summaryrefslogtreecommitdiff
path: root/source4/autogen.sh
diff options
context:
space:
mode:
authorKai Blin <kai@samba.org>2008-02-11 11:57:17 +0100
committerKai Blin <kai@samba.org>2008-02-11 11:58:43 +0100
commitde03c4a3eadd8180e5bda5b176f1abebff613a15 (patch)
tree65e0b4654f2cb935c75beaf60cf71ef8943165c2 /source4/autogen.sh
parentd82b6dd09adc0b30567ffcc9e47553eb3ed51b2a (diff)
downloadsamba-de03c4a3eadd8180e5bda5b176f1abebff613a15.tar.gz
samba-de03c4a3eadd8180e5bda5b176f1abebff613a15.tar.bz2
samba-de03c4a3eadd8180e5bda5b176f1abebff613a15.zip
autoconf: We build Samba from git now, not from SVN.
(This used to be commit 4557b34d82e16038db903278ea64313a9d731d61)
Diffstat (limited to 'source4/autogen.sh')
-rwxr-xr-xsource4/autogen.sh14
1 files changed, 7 insertions, 7 deletions
diff --git a/source4/autogen.sh b/source4/autogen.sh
index 9c73c96572..b721a45a99 100755
--- a/source4/autogen.sh
+++ b/source4/autogen.sh
@@ -1,9 +1,9 @@
#!/bin/sh
# Run this script to build samba from SVN.
## insert all possible names (only works with
## autoconf 2.x
TESTAUTOHEADER="autoheader autoheader-2.53 autoheader2.50 autoheader259 autoheader253"
TESTAUTOCONF="autoconf autoconf-2.53 autoconf2.50 autoconf259 autoconf253"
@@ -12,7 +12,7 @@ AUTOCONFFOUND="0"
##
-## Look for autoheader
+## Look for autoheader
##
for i in $TESTAUTOHEADER; do
if which $i > /dev/null 2>&1; then
@@ -24,7 +24,7 @@ for i in $TESTAUTOHEADER; do
fi
done
-##
+##
## Look for autoconf
##
@@ -39,11 +39,11 @@ for i in $TESTAUTOCONF; do
done
-##
+##
## do we have it?
##
if test "$AUTOCONFFOUND" = "0" -o "$AUTOHEADERFOUND" = "0"; then
- echo "$0: need autoconf 2.53 or later to build samba from SVN" >&2
+ echo "$0: need autoconf 2.53 or later to build samba from git" >&2
exit 1
fi
@@ -1,9 +1,9 @@
#!/bin/sh
-# Run this script to build samba from SVN.
+# Run this script to build samba from git.
-## insert all possible names (only works with
-## autoconf 2.x
+## insert all possible names (only works with
+## autoconf 2.x)
TESTAUTOHEADER="autoheader autoheader-2.53 autoheader2.50 autoheader259 autoheader253"
TESTAUTOCONF="autoconf autoconf-2.53 autoconf2.50 autoconf259 autoconf253"